pisa.psa.cols: Character vector representing the list of covariates used for estimating
propensity scores.
Description
Character vector representing the list of covariates used for estimating
propensity scores.
Format
a character vector with covariate names for estimating propensity scores.