This is a crude measure of overall balance. Absolute
value of the standardized effect sizes are calculated for
each covariate. Overall balance statistics are the mean
of those effect sizes after adjustement for each method
across all bootstrap samples.
Usage
## S3 method for class 'PSAboot.balance':
print(x, na.rm = TRUE, ...)