should NAs be removed. NAs generally occur when there is insufficient
sample for a particular covariate or an unused level.
pool.fun
a function specifying how the effect sizes across all covariates
should be combined. Possible values include mean (default),
q25, q75, median, max, or
any function that takes a vector of numeric values.