Learn R Programming

PSAboot (version 1.1.3)

balance: Returns a summary of the balance for all bootstrap samples.

Description

This method provides some crude overall measures of balance.

Usage

balance(psaboot, na.rm = TRUE, pool.fun = mean)

Arguments

psaboot
results from PSAboot.
na.rm
should NAs be removed. NAs generally occur when there is insufficient sample for a particular covariate or an unused level.
pool.fun
a function specifying how the effect sizes across all covariates should be combined. Possible values include mean (default), q25, q75, median

Value

  • a list with three elements: [object Object],[object Object],[object Object],[object Object]