Rdocumentation
powered by
Learn R Programming
PSAboot (version 1.1.4)
balance.matching: Returns balance for each covariate from propensity score matching.
Description
Returns balance for each covariate from propensity score matching.
Usage
balance.matching(index.treated, index.control, covs)
Arguments
index.treated
a vector with the index of treated rows in
covs
.
index.control
a vector with the index of control rows in
covs
.
covs
data frame or matrix of covariates. Factors should already be recoded. See
cv.trans.psa
Value
a named vector with one element per covariate.