Learn R Programming

PSAboot (version 1.0)

pisa.psa.cols: Character vector representing the list of covariates used for estimating propensity scores.

Description

Character vector representing the list of covariates used for estimating propensity scores.

Arguments

format

a character vector with covariate names for estimating propensity scores.