Learn R Programming

PSAboot (version 1.0)

pisausa: Programme of International Student Assessment (PISA) results from the United States in 2009.

Description

Student results from the 2009 Programme of International Student Assessment (PISA) as provided by the Organization for Economic Co-operation and Development (OECD). See http://www.pisa.oecd.org/ for more information including the code book.

Arguments

Details

Note that missing values have been imputed using the mice{http://cran.r-project.org/web/packages/mice/index.html} package. Details on the specific procedure are in the pisa.impute function in the http://github.com/jbryer/pisa{pisa package}.

References

Organisation for Economic Co-operation and Development (2009). Programme for International Student Assessment (PISA). http://www.pisa.oecd.org/